@@ -107,65 +107,62 @@ inline bool operator!=(Opcode a, Opcode b)
 }
 
 namespace detail {
-template <typename T>
-void vector_slice(std::vector<T>& new_vec, const std::vector<T>& vec, int start, int stop, int step)
+template <typename Vec>
+auto vector_slice(const Vec& vec, int start, int stop, int step) -> Vec
 {
-    if (step > 0) {
-        if (start < 0) {
-            start = std::max<int>(start + static_cast<int>(vec.size()), 0);
-        }
-        else if (start > static_cast<int>(vec.size())) {
-            start = static_cast<int>(vec.size());
-        }
+    Vec new_vec;
 
-        if (stop < 0) {
-            stop = std::max<int>(stop + static_cast<int>(vec.size()), 0);
-        }
-        else if (stop > static_cast<int>(vec.size())) {
-            stop = static_cast<int>(vec.size());
-        }
+    if (step == 0) throw std::invalid_argument("slice step cannot be zero");
+    if (step < 0) throw std::invalid_argument("step sizes below 0 lead to an invalid order of editops");
 
-        if (start >= stop) {
-            return;
-        }
+    if (start < 0)
+        start = std::max<int>(start + static_cast<int>(vec.size()), 0);
+    else if (start > static_cast<int>(vec.size()))
+        start = static_cast<int>(vec.size());
 
-        int count = (stop - 1 - start) / step + 1;
-        new_vec.reserve(static_cast<size_t>(count));
+    if (stop < 0)
+        stop = std::max<int>(stop + static_cast<int>(vec.size()), 0);
+    else if (stop > static_cast<int>(vec.size()))
+        stop = static_cast<int>(vec.size());
 
-        for (int i = start; i < stop; i += step) {
-            new_vec.push_back(vec[static_cast<size_t>(i)]);
-        }
-    }
-    else if (step < 0) {
-        if (start < 0) {
-            start = std::max<int>(start + static_cast<int>(vec.size()), -1);
-        }
-        else if (start >= static_cast<int>(vec.size())) {
-            start = static_cast<int>(vec.size()) - 1;
-        }
+    if (start >= stop) return new_vec;
 
-        if (stop < 0) {
-            stop = std::max<int>(stop + static_cast<int>(vec.size()), -1);
-        }
-        else if (stop >= static_cast<int>(vec.size())) {
-            stop = static_cast<int>(vec.size()) - 1;
-        }
+    int count = (stop - 1 - start) / step + 1;
+    new_vec.reserve(static_cast<size_t>(count));
 
-        if (start <= stop) {
-            return;
-        }
+    for (int i = start; i < stop; i += step)
+        new_vec.push_back(vec[static_cast<size_t>(i)]);
 
-        int count = (stop + 1 - start) / step + 1;
-        new_vec.reserve(static_cast<size_t>(count));
-
-        for (int i = start; i > stop; i += step) {
-            new_vec.push_back(vec[static_cast<size_t>(i)]);
-        }
-    }
-    else {
-        throw std::invalid_argument("slice step cannot be zero");
-    }
+    return new_vec;
 }
+
+template <typename Vec>
+void vector_remove_slice(Vec& vec, int start, int stop, int step)
+{
+    if (step == 0) throw std::invalid_argument("slice step cannot be zero");
+    if (step < 0) throw std::invalid_argument("step sizes below 0 lead to an invalid order of editops");
+
+    if (start < 0)
+        start = std::max<int>(start + static_cast<int>(vec.size()), 0);
+    else if (start > static_cast<int>(vec.size()))
+        start = static_cast<int>(vec.size());
+
+    if (stop < 0)
+        stop = std::max<int>(stop + static_cast<int>(vec.size()), 0);
+    else if (stop > static_cast<int>(vec.size()))
+        stop = static_cast<int>(vec.size());
+
+    if (start >= stop) return;
+
+    auto iter = vec.begin() + start;
+    for (int i = start; i < static_cast<int>(vec.size()); i++)
+        if (i >= stop || ((i - start) % step != 0))
+            *(iter++) = vec[static_cast<size_t>(i)];
+
+    vec.resize(static_cast<size_t>(std::distance(vec.begin(), iter)));
+    vec.shrink_to_fit();
+}
+
 } // namespace detail
 
 class Opcodes;
@@ -244,13 +241,17 @@ public:
 
     Editops slice(int start, int stop, int step = 1) const
     {
-        Editops ed_slice;
-        detail::vector_slice(ed_slice, *this, start, stop, step);
+        Editops ed_slice = detail::vector_slice(*this, start, stop, step);
         ed_slice.src_len = src_len;
         ed_slice.dest_len = dest_len;
         return ed_slice;
     }
 
+    void remove_slice(int start, int stop, int step = 1)
+    {
+        detail::vector_remove_slice(*this, start, stop, step);
+    }
+
     Editops reverse() const
     {
         Editops reversed = *this;
@@ -281,12 +282,10 @@ public:
         std::swap(inv_ops.src_len, inv_ops.dest_len);
         for (auto& op : inv_ops) {
             std::swap(op.src_pos, op.dest_pos);
-            if (op.type == EditType::Delete) {
+            if (op.type == EditType::Delete)
                 op.type = EditType::Insert;
-            }
-            else if (op.type == EditType::Insert) {
+            else if (op.type == EditType::Insert)
                 op.type = EditType::Delete;
-            }
         }
         return inv_ops;
     }
@@ -435,8 +434,7 @@ public:
 
     Opcodes slice(int start, int stop, int step = 1) const
     {
-        Opcodes ed_slice;
-        detail::vector_slice(ed_slice, *this, start, stop, step);
+        Opcodes ed_slice = detail::vector_slice(*this, start, stop, step);
         ed_slice.src_len = src_len;
         ed_slice.dest_len = dest_len;
         return ed_slice;
@@ -473,12 +471,10 @@ public:
         for (auto& op : inv_ops) {
             std::swap(op.src_begin, op.dest_begin);
             std::swap(op.src_end, op.dest_end);
-            if (op.type == EditType::Delete) {
+            if (op.type == EditType::Delete)
                 op.type = EditType::Insert;
-            }
-            else if (op.type == EditType::Insert) {
+            else if (op.type == EditType::Insert)
                 op.type = EditType::Delete;
-            }
         }
         return inv_ops;
     }
@@ -490,13 +486,10 @@ private:
 
 inline bool operator==(const Opcodes& lhs, const Opcodes& rhs)
 {
-    if (lhs.get_src_len() != rhs.get_src_len() || lhs.get_dest_len() != rhs.get_dest_len()) {
-        return false;
-    }
+    if (lhs.get_src_len() != rhs.get_src_len() || lhs.get_dest_len() != rhs.get_dest_len()) return false;
+
+    if (lhs.size() != rhs.size()) return false;
 
-    if (lhs.size() != rhs.size()) {
-        return false;
-    }
     return std::equal(lhs.begin(), lhs.end(), rhs.begin());
 }
 
@@ -519,21 +512,18 @@ inline Editops::Editops(const Opcodes& other)
         case EditType::None: break;
 
         case EditType::Replace:
-            for (size_t j = 0; j < op.src_end - op.src_begin; j++) {
+            for (size_t j = 0; j < op.src_end - op.src_begin; j++)
                 push_back({EditType::Replace, op.src_begin + j, op.dest_begin + j});
-            }
             break;
 
         case EditType::Insert:
-            for (size_t j = 0; j < op.dest_end - op.dest_begin; j++) {
+            for (size_t j = 0; j < op.dest_end - op.dest_begin; j++)
                 push_back({EditType::Insert, op.src_begin, op.dest_begin + j});
-            }
             break;
 
         case EditType::Delete:
-            for (size_t j = 0; j < op.src_end - op.src_begin; j++) {
+            for (size_t j = 0; j < op.src_end - op.src_begin; j++)
                 push_back({EditType::Delete, op.src_begin + j, op.dest_begin});
-            }
             break;
         }
     }
